@@ -1,8 +1,9 @@
 use warnings;
 use strict;
-package TextFileParser 0.1821900;
 
-# ABSTRACT: a Perl extension to ease the parsing of text files. Can be used as a base class to write your own parser.
+package TextFileParser 0.1821902;
+
+# ABSTRACT: an extensible Perl class to parse any text file by specifying grammar in derived classes.
 
 use Exporter 'import';
 our (@EXPORT_OK) = ();
@@ -98,7 +99,7 @@ sub lines_parsed {
 
 sub __try_to_parse {
     my ( $self, $line ) = @_;
-    try { $self->make_sense_of_line($line); }
+    try { $self->save_record($line); }
     catch {
         $self->__close_file;
         $_->rethrow;
@@ -106,14 +107,9 @@ sub __try_to_parse {
 }
 
 
-sub make_sense_of_line {
-    my $self = shift;
-    $self->save_record(shift);
-}
-
-
 sub save_record {
     my $self = shift;
+    return if not @_;
     $self->{__records} = [] if not exists $self->{__records};
     push @{ $self->{__records} }, shift;
 }
@@ -155,11 +151,11 @@ __END__
 
 =head1 NAME
 
-TextFileParser - a Perl extension to ease the parsing of text files. Can be used as a base class to write your own parser.
+TextFileParser - an extensible Perl class to parse any text file by specifying grammar in derived classes.
 
 =head1 VERSION
 
-version 0.1821900
+version 0.1821902
 
 =head1 SYNOPSIS
 
@@ -177,7 +173,7 @@ Here's another parser which is derived from C<TextFileParser> as the base class.
 
     use strict;
     use warnings;
-    package AnotherParser;
+    package WordCounter;
     use parent 'TextFileParser';
     use Exception::Class (
         'SomeException' => {
@@ -186,13 +182,13 @@ Here's another parser which is derived from C<TextFileParser> as the base class.
         }
     );
 
-    sub make_sense_of_line {
+    sub save_record {
         my ($self, $line) = @_;
         my (@words) = split /\s+/, $line;
         throw_some_error 
             error => $self->filename . ': expected at least one character: ' . $self->lines_parsed
                 if not @words;
-        $self->save_record(\@words);
+        $self->SUPER::save_record(\@words);
     }
 
     package main;
@@ -200,7 +196,7 @@ Here's another parser which is derived from C<TextFileParser> as the base class.
     use Try::Tiny;
 
     try {
-        my $a_parser = new AnotherParser;
+        my $a_parser = new WordCounter;
         $a_parser->read(shift @ARGV);
         print Dumper($a_parser->get_records);
     } catch {
@@ -235,7 +231,7 @@ Returns once all records have been read or if an exception is thrown for any par
         print STDERR $_, "\n";
     }
 
-You're better-off not overriding this subroutine. Override C<make_sense_of_line> instead. If you want to intervene in the file C<open> step you can't do it for now. A new version will explain how you can do that.
+You're better-off not overriding this subroutine. Override C<save_record> instead. If you want to intervene in the file C<open> step you can't do it for now. A new version will explain how you can do that.
 
 =head2 filename
 
@@ -249,62 +245,41 @@ Takes no arguments. Returns the number of lines last parsed.
 
 This is also very useful for error message generation. See example under L<Synopsis|/SYNOPSIS>.
 
-=head2 make_sense_of_line
+=head2 save_record
 
-Takes exactly one string argument. This method can be overridden in derived classes to extract the relevant information from each line and store records. In general once the relevant data has been collected, you would want to call C<save_record>. By default, this method saves the input string as the record. When you override this method, remember to either do that or call the C<SUPER::make_sense_of_line> method.
+Takes exactly one string argument. This method can be overridden in derived classes to extract the relevant information from each line and store records. In general once the relevant data has been collected, you would want to call C<SUPER::save_record>. By default, this method saves the input string as the record.
 
-See L<Synopsis|/SYNOPSIS> for how a derived class could write their own method to handle data. Below is an alternative way to override the method without calling C<save_record>.
+See L<Synopsis|/SYNOPSIS> for how a derived class could write their own method to handle data.
 
     package MyParser;
     use parent 'TextFileParser';
 
-    sub make_sense_of_line {
+    sub save_record {
         my ($self, $line) = @_;
         my $data = __extract_some_info($line);
-        $self->SUPER::make_sense_of_line($data);
+        $self->SUPER::save_record($data);
     }
 
-Here's another example when you want to append the data from current line to the data collected from a previous line. In the below example, if a line starts with a C<'+'> character then it is to be treated as a continuation of the previous line. Otherwise, any line that begins with anything other than C<'+'> is to be treated as a new record.
+Here's an example of a parser that reads multi-line records: if a line starts with a C<'+'> character then it is to be treated as a continuation of the previous line.
 
     use strict;
     use warnings;
-    package MultilineParser;
+    package MultilineWordCounter;
     use parent 'TextFileParser';
-    use Exception::Class (
-        'NothingOnLine', 
-    );
 
-    sub make_sense_of_line {
+    sub save_record {
         my ($self, $line) = @_;
         my (@words) = split /\s+/, $line;
-        $self->__throw_an_exception if not @words;
-        my $method = ($words[0] eq '+') ? '__append_last_record' : '__save_new_record';
-        $self->$method(@words);
+        my $method = ($#words >= 0 and $words[0] eq '+') ? '__append_last_record' : 'SUPER::save_record';
+        $self->$method(\@words);
     }
 
     sub __append_last_record {
-        my ($self, $plus, @words) = @_;
-        $self->__throw_an_exception if not @words;
+        my ($self, $plus, $words) = @_;
         my $last_rec = $self->last_record;
-        push @{last_rec}, @words;
+        push @{last_rec}, @{$words};
     }
 
-    sub __save_new_record {
-        my ($self, @words) = @_;
-        $self->save_record(\@words);
-    }
-
-    sub __throw_an_exception {
-        my $self = shift;
-        NothingOnLine->throw error => 'Nothing on line: '.$self->lines_parsed;
-    }
-
-=head2 save_record
-
-Takes exactly one argument. It will save the argument as a record. You can save any data as long as you make it all into one single variable. It can be a reference to an array or a hash or whatever you like. But there must be one unit of data ; if no arguments are given to a call of C<save_record> it will save C<undef>.
-
-See many examples above to see how this can be used.
-
 =head2 get_records
 
 Takes no arguments. Returns an array containing all the records that were read by the parser.
